@@ -15,11 +15,11 @@ class SectionForm(forms.ModelForm):
     def save(self, *args, **kwargs):
         """
         We're overriding this because we don't want to use Django's ORM to
-        create new nodes. django-treebeard has it's own node creation methods
+        create new nodes. Django-treebeard has it's own node creation methods
         which should be used instead. To make sure no one actually uses this
-        ModelForm to do that, calling it's save method will raise a 
-        NotImplemented exception, **unless an instance has been supplied**. In
-        that case, we're just updating an existing node, so using the ORM to 
+        ``ModelForm`` to do that, calling it's save method will raise a 
+        ``NotImplemented`` exception, **unless an instance has been supplied**. 
+        In that case, we're just updating an existing node, so using the ORM to 
         save is fine.
         """
         if hasattr(self, 'instance') and self.instance:
